@@ -2,6 +2,7 @@ from django.conf.urls.defaults import patterns, url
 from feeds import LatestEntriesFeed
 import settings
 from sitemap import BlogSitemap
+from django.contrib.sitemaps.views import sitemap
 
 sitemaps = {
     'posts': BlogSitemap,
@@ -9,7 +10,7 @@ sitemaps = {
 
 urlpatterns = patterns('fancy.blog.views',
     url(r'^$', 'index', name='post_index'),
-    url(r'^sitemap\.xml$', 'django.contrib.sitemaps.views.sitemap', {'sitemaps': sitemaps}),
+    url(r'^sitemap\.xml$', sitemap, {'sitemaps': sitemaps}),
     url(r'^rss/$', LatestEntriesFeed()),
 	url(r'^(?P<year>[\d]{4})/$','year_index', name='post_year_index'),
 	url(r'^(?P<year>[\d]{4})/(?P<month>[\d]{2})/$','month_index', name='post_month_index'),
